@@ -4,6 +4,7 @@ from datetime import date, datetime, time, timedelta
 from dotenv import load_dotenv
 from url_remote.environment_name_enum import EnvironmentName
 from urllib.parse import urlparse
+from http_constants import status
 
 from .mini_logger import MiniLogger as logger
 
@@ -251,11 +252,10 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
 
 # Former name was create_http_headers()
 def create_authorization_http_headers(user_jwt: str) -> dict:
-    http_headers = {
+    return {
         'Content-Type': 'application/json',
         'Authorization': f'Bearer {user_jwt}',
     }
-    return http_headers
 
 
 def get_jwt_from_event(event: dict) -> str:
@@ -271,6 +271,20 @@ def create_return_http_headers() -> dict:
         "Access-Control-Allow-Origin": "*",
     }
 
+def create_error_http_response(exception: Exception) -> dict:
+    return {
+            "statusCode": status.BAD_GATEWAY,
+            "headers": create_return_http_headers(),
+            "body": create_http_body({"error": str(exception)})
+        }
+
+def create_ok_http_response(body: dict) -> dict:
+    return {
+        "statusCode": status.OK,
+        "headers": create_return_http_headers(),
+        "body": create_http_body(body)
+    }
+
 
 # https://google.github.io/styleguide/jsoncstyleguide.xml?showone=Property_Name_Format#Property_Name_Format
 def create_http_body(body: dict) -> str:
